@@ -182,11 +182,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.2.3
+Version v3.2.4
 
 =cut
 
-our $VERSION = version->declare('v3.2.3');
+our $VERSION = version->declare('v3.2.4');
 
 =head1 SYNOPSIS
 
@@ -585,6 +585,10 @@ sub clean_cruft_and_spaces
 {
 	local $_ = shift or return q{};
 
+	# strip trailing dash, assuming it is soft-wrap
+	# (example: disclaimers in GNU autotools file "install-sh")
+	s/-\r?\n//;
+
 	tr/\t\r\n/ /;
 
 	# this also removes quotes
@@ -594,17 +598,39 @@ sub clean_cruft_and_spaces
 	return $_;
 }
 
+my $any           = '[A-Za-z_][A-Za-z0-9_]*';
+my $str           = '[A-Za-z][A-Za-z0-9_]*';
+my $re_prop_attrs = qr/
+	\A(?'prop'$str)\.alt(?:
+		\.org\.(?'org'$str)|
+		\.version\.(?'version'$str)|
+		\.since\.date_(?'since_date'\d{8})|
+		\.until\.date_(?'until_date'\d{8})|
+		\.synth\.$any|
+		(?'other'\.$any)
+	)*\z/x;
+
 sub best_value
 {
-	my ( $self, $hashref, @keys ) = @_;
+	my ( $self, $hashref, @props ) = @_;
 	my $value;
 
-	for my $key (@keys) {
+	PROPERTY:
+	for my $prop (@props) {
 		for my $org ( @{ $self->shortname_scheme } ) {
-			$value ||= $hashref->{"$key.alt.org.$org"};
-			$value ||= $hashref->{"$key.alt.org.$org.synth.nogrant"};
+			for ( keys %$hashref ) {
+				/$re_prop_attrs/;
+				next unless $+{prop} and $+{prop} eq $prop;
+				next unless $+{org}  and $+{org} eq $org;
+				next if $+{version};
+				next if $+{other};
+				next if $+{until_date};
+
+				$value = $hashref->{$_};
+				last PROPERTY;
+			}
 		}
-		$value ||= $hashref->{$key};
+		$value ||= $hashref->{$prop};
 	}
 
 	return $value;
